@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "helm-rtags" "3.23"
+(define-package "helm-rtags" "20250801.1647"
   "A front-end for rtags."
   '((helm  "2.0")
     (rtags "2.10"))
-  :url "http://rtags.net"
-  :commit "7169ed577d676690a3c6f0025b54e8477d80eacf"
-  :revdesc "v3.23-0-g7169ed577d67"
+  :url "https://github.com/Andersbakken/rtags"
+  :commit "dd6b20f7e57a30f32a8ccbb6c22038383dba746b"
+  :revdesc "dd6b20f7e57a"
   :authors '(("Jan Erik Hanssen" . "jhanssen@gmail.com")
              ("Anders Bakken" . "agbakken@gmail.com"))
   :maintainers '(("Jan Erik Hanssen" . "jhanssen@gmail.com")
